Keyboard shortcuts — Pootle 2.5.0 documentation

# Keyboard shortcuts

New in version 2.5.

## Global

Action | Shortcut
--- | ---
Content Zoom Out | `Ctrl+Shift+-`
Reset Content Zoom | `Ctrl+Shift+0`
Content Zoom In | `Ctrl+Shift+"+"`

## Editing

Action | Current shortcut | Proposed shortcut
--- | --- | ---
Submit and move to next translation | `Ctrl+Enter` |
Toggle the fuzzy flag | `Ctrl+Space` |
Toggle the suggest/submit mode | `Ctrl+Shift+Space` |
Copy the contents from the original language |  | `Alt+Down`
Focus on comments field |  | `Ctrl+Shift+C`

## Navigation

Action | Shortcut
--- | ---
Move to previous string | `Ctrl+Up`
Move to next string | `Ctrl+Down`
Move to the first string | `Ctrl+Shift+Home`
Move to the last string | `Ctrl+Shift+End`
Move up 10 strings | `Ctrl+Shift+Page Up`
Move down 10 strings | `Ctrl+Shift+Page Down`
Select search box | `Ctrl+Shift+S`
Select page number | `Ctrl+Shift+N`